<?php
session_start(); // Start session to manage user login state
include 'header.php';
include 'db.php'; // Include database connection

// Initialize message variable
$message = "";

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['register'])) {
    $name = $_POST['name'];
    $phone = $_POST['phone'];
    $referral_code = isset($_POST['referral_code']) ? $_POST['referral_code'] : '';

    if (!validatePhone($phone)) {
        $message = "Invalid phone number. Must be 10 digits.";
    } else {
        // Check if phone is already registered
        $stmt = $conn->prepare("INSERT INTO MLM_users (name, phone, reference_number, approved, my_number) VALUES (?, ?, ?, 0, NULL)");
        if ($stmt) {
            $stmt->bind_param("sss", $name, $phone, $referral_code);
            if ($stmt->execute()) {
                $message = 'Registration successful! Please log in.';
            } else {
                $message = 'Registration failed: ' . $stmt->error;
            }
            $stmt->close();
        } else {
            $message = 'Failed to prepare statement for user insertion.';
        }

    }
}

function validatePhone($phone)
{
    return preg_match('/^\d{10}$/', $phone); // Ensures the phone number is exactly 10 digits
}

?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">Add User</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">Add User</li>
        </ul>
    </div>

    <div class="card h-100 p-0 radius-12">
        <div class="card-body p-24">
            <?php if ($message): ?>
                <div class="alert alert-warning"><?php echo htmlspecialchars($message); ?></div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <div class="col-xxl-6 col-xl-8 col-lg-10">
                    <div class="card border">
                        <div class="card-body">
                            <h6 class="text-md text-primary-light mb-16">User Information</h6>
                            <form action="" method="POST"> <!-- Use POST method -->
                                <div class="mb-20">
                                    <label for="name"
                                        class="form-label fw-semibold text-primary-light text-sm mb-8">Full Name <span
                                            class="text-danger-600">*</span></label>
                                    <input type="text" name="name" class="form-control radius-8" id="name"
                                        placeholder="Enter Full Name" required>
                                </div>
                                <div class="mb-20">
                                    <label for="phone"
                                        class="form-label fw-semibold text-primary-light text-sm mb-8">Phone <span
                                            class="text-danger-600">*</span></label>
                                    <input type="text" name="phone" class="form-control radius-8" id="phone"
                                        placeholder="Enter phone number " pattern="\d{10}" maxlength="10" minlength="10"
                                        title="Phone number must be exactly 10 digits" required>
                                </div>

                                <div class="mb-20">
                                    <label for="referral_code"
                                        class="form-label fw-semibold text-primary-light text-sm mb-8">Referral
                                        Code</label>
                                    <input type="text" name="referral_code" class="form-control radius-8"
                                        id="referral_code" placeholder="Enter referral code">
                                </div>
                                <div class="d-flex align-items-center justify-content-center gap-3">
                                    <button type="button"
                                        class="border border-danger-600 bg-hover-danger-200 text-danger-600 text-md px-56 py-11 radius-8">
                                        Cancel
                                    </button>
                                    <button type="submit" name="register"
                                        class="btn btn-primary border border-primary-600 text-md px-56 py-12 radius-8">
                                        Save
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>