<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_start(); // Start session to store user login information



if (!isset($_SESSION['id'])) {
    header("Location: index.php"); // Redirect to login page if not logged in
    exit;
}

include 'db.php'; 

// Function to log errors
function logError($message) {
    error_log($message, 3, "error_log.log");
}

// Function to insert wallet transaction
function insertWalletTransaction($conn, $user_id, $amount, $description) {
    $stmt = $conn->prepare("INSERT INTO wallet_transactions (user_id, amount, description, created_at, wallet_type) VALUES (?, ?, ?, NOW(), 'add')");
    $stmt->bind_param("ids", $user_id, $amount, $description);
    
    if (!$stmt->execute()) {
        logError("Failed to insert transaction for user ID $user_id: " . $stmt->error);
    }
    
    $stmt->close();
}

// Function to generate a unique my_number
function generateMyNumber($conn) {
    do {
        $random_number = rand(1000, 9999);
        $my_number = "MLM@" . $random_number;

        // Check for uniqueness
        $stmt = $conn->prepare("SELECT COUNT(*) FROM MLM_users WHERE my_number = ?");
        $stmt->bind_param("s", $my_number);
        $stmt->execute();
        $stmt->bind_result($count);
        $stmt->fetch();
        $stmt->close();
    } while ($count > 0);

    return $my_number;
}

// Function to approve user and handle bonuses
function approveUser($conn, $user_id) {
    // Fetch user details
    $stmt = $conn->prepare("SELECT my_number, reference_number FROM MLM_users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($my_number, $reference_number);
    $stmt->fetch();
    $stmt->close();

    // If user has no my_number, generate one
    if (empty($my_number)) {
        $my_number = generateMyNumber($conn);
    }

    // Update user approval status and my_number
    $stmt = $conn->prepare("UPDATE MLM_users SET approved = 1, my_number = ? WHERE id = ?");
    $stmt->bind_param("si", $my_number, $user_id);
    $stmt->execute();
    $stmt->close();

    // Distribute bonuses
    distributeBonuses($conn, $my_number, $reference_number, $user_id);
}

// Function to distribute bonuses
function distributeBonuses($conn, $my_number, $reference_number, $approved_user_id) {
    $bonus_amount_25 = 200 * 0.25; // 25% of 200
    $bonus_amount_5 = 200 * 0.05;  // 5% of 200

    // 25% bonus distribution: Find users whose my_number matches the approved user's reference_number
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($bonus_user_25 = $result->fetch_assoc()) {
        $bonus_user_id_25 = $bonus_user_25['id'];

        // Update balance for the 25% bonus
        $update_balance_stmt_25 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_25->bind_param("di", $bonus_amount_25, $bonus_user_id_25);
        $update_balance_stmt_25->execute();
        $update_balance_stmt_25->close();

        // Insert transaction for 25% bonus
        insertWalletTransaction($conn, $bonus_user_id_25, $bonus_amount_25, "25% bonus for referencing $my_number");

        // Distribute 5% bonuses recursively
        distributeFivePercentBonus($conn, $bonus_user_id_25, $bonus_amount_5, $approved_user_id);
    }
}

// Recursive function to distribute 5% bonuses
function distributeFivePercentBonus($conn, $bonus_user_id_25, $bonus_amount_5, $approved_user_id) {
    // Fetch the reference_number of the user who received the 25% bonus
    $stmt = $conn->prepare("SELECT reference_number FROM MLM_users WHERE id = ?");
    $stmt->bind_param("i", $bonus_user_id_25);
    $stmt->execute();
    $stmt->bind_result($reference_number);
    $stmt->fetch();
    $stmt->close();

    // Stop if no reference_number is found
    if (empty($reference_number)) {
        return;
    }

    // Find users whose my_number matches the reference_number
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($bonus_user_5 = $result->fetch_assoc()) {
        $bonus_user_id_5 = $bonus_user_5['id'];

        // Skip the approved user
        if ($bonus_user_id_5 == $approved_user_id) {
            continue;
        }

        // Update balance for the 5% bonus
        $update_balance_stmt_5 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_5->bind_param("di", $bonus_amount_5, $bonus_user_id_5);
        $update_balance_stmt_5->execute();
        $update_balance_stmt_5->close();

        // Insert transaction for 5% bonus
        insertWalletTransaction($conn, $bonus_user_id_5, $bonus_amount_5, "5% bonus for referencing the 25% bonus user");

        // Recursively distribute 5% bonuses to the next user
        distributeFivePercentBonus($conn, $bonus_user_id_5, $bonus_amount_5, $approved_user_id);
    }
}

// Handle approval action
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    $user_id = $_POST['user_id'];
    if ($_POST['action'] === 'approve') {
        approveUser($conn, $user_id);
    } 
}

// Get all users details
$user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users");
$user_stmt->execute();
$user_result = $user_stmt->get_result();

// Fetch all users
$users = $user_result->fetch_all(MYSQLI_ASSOC);
$user_stmt->close();
?>

<?php include 'header.php'; ?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">User Management</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    All Users
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">User List</li>
        </ul>
    </div>

    <div class="card basic-data-table">
        <div class="card-header">
            <h5 class="card-title mb-0">All Users</h5>
        </div>
        <div class="card-body">
            <div style="overflow-x: auto; white-space: nowrap;">
                <table class="table bordered-table mb-0" id="dataTable" data-page-length='10' style="min-width: 800px;">
                    <thead>
                        <tr>
                            <th scope="col">S.L</th>
                            <th scope="col">ID</th>
                            <th scope="col">Name</th>
                            <th scope="col">Phone</th>
                            <th scope="col">Reference Number</th>
                            <th scope="col">My Number</th>
                            <th scope="col">Created At</th>
                            <th scope="col">Total Balance</th>
                            <th scope="col">Approved</th>
                            <th scope="col">Action</th>
                            <th scope="col">Reports</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($users as $index => $user): ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo htmlspecialchars($user['id']); ?></td>
                                <td><?php echo htmlspecialchars($user['name']); ?></td>
                                <td><?php echo htmlspecialchars($user['phone']); ?></td>
                                <td><?php echo htmlspecialchars($user['reference_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['my_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['created_at']); ?></td>
                                <td><?php echo htmlspecialchars($user['total_balance']); ?></td>
                                <td>
                                    <form method="POST">
                                        <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                        <select name="action" onchange="this.form.submit()">
                                            <option value="approve" <?php if ($user['approved'] == 1) echo 'selected'; ?>>Yes</option>
                                            <option value="disapprove" <?php if ($user['approved'] == 0) echo 'selected'; ?>>No</option>
                                        </select>
                                    </form>
                                </td>
                                <td>

                <a href="user-edit.php?user_id=<?php echo $user['id']; ?>" class="w-32-px h-32-px bg-success-focus text-success-main rounded-circle d-inline-flex align-items-center justify-content-center">
    <iconify-icon icon="lucide:edit"></iconify-icon>
</a>

                <a href="javascript:void(0)" class="w-32-px h-32-px bg-danger-focus text-danger-main rounded-circle d-inline-flex align-items-center justify-content-center">
                  <iconify-icon icon="mingcute:delete-2-line"></iconify-icon>
                </a>
              </td>
                                  <td>
 <a href="user-report.php?user_id=<?php echo $user['id']; ?>" class="w-32-px h-32-px bg-success-focus text-success-main rounded-circle d-inline-flex align-items-center justify-content-center">
 <iconify-icon icon="iconamoon:eye-light">Reports</iconify-icon></a>
               
              </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>
