<?php
session_start(); 

include 'db.php'; 

$hide_chart = true;

include 'header.php';

// Check if user_id is already set in the session
$userId = 33;

if (!isset($_SESSION['user_id'])) {
    $_SESSION['user_id'] = $userId; // Store the user ID in the session
}

// Prepare and execute the query to fetch user information
$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

// Check if any user was found
if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; // Assuming 'reference_number' holds the referenced user's ID
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Function to fetch total amounts based on wallet type and optionally a date condition
function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    // Append date condition if provided
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; // Return total or 0 if null
}

// Fetch balances and withdrawals with error handling
$userBalance = fetchTotalAmount($conn, $userId, 'add'); // Total balance
if ($userBalance === false) {
    die("Error fetching user balance."); // Handle error in fetching user balance
}

$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal'); // Total withdrawals
if ($userWithdraw === false) {
    die("Error fetching user withdrawals."); // Handle error in fetching user withdrawals
}

// Ensure withdrawals are treated as positive for calculation
$userWithdraw = abs($userWithdraw); // Convert withdrawals to positive if needed

// Calculate net balance
$netBalance = $userBalance - $userWithdraw; // Correctly calculate net balance

// Display net balance
// echo "Net Balance = " . $userBalance . " - " . $userWithdraw . " = " . $netBalance . "<br>";

// Fetch today's balance and withdrawals
$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals

// Fetch reference user's total balance
$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

// Fetch count of users who used the current user's reference number
$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

// Fetch count of users referred by the current user today
$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;


?>


<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">Dashboard </h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">Summary</li>
        </ul>
    </div>

    <style>
        .myicon {
            margin-right: 6px; /* Increased space between icon and text */
        }
    </style>

    <div class="row gy-4">
        <div class="col-lg-12">
            <div class="shadow-4 border radius-8" style="background-color: white;">
                <div class="p-20">
                    <?php if ($user['approved'] == 0): ?>
                        <p>Thank you for registering! Please pay your fees using the QR code below and send a screenshot to this phone number: <strong>6353818433</strong></p>
                        <img src="https://upload.wikimedia.org/wikipedia/commons/thumb/d/d0/QR_code_for_mobile_English_Wikipedia.svg/800px-QR_code_for-mobile_English_Wikipedia.svg.png" alt="QR Code">
                    <?php else: ?>
                        <div class="row">
    <!-- Left side -->
    <div class="col-6">
        <p><strong><i class="ri-user-line myicon"></i>Name :</strong> <?php echo htmlspecialchars($user['name']); ?></p>
        <p><strong><i class="ri-phone-line myicon"></i>Phone :</strong> <?php echo htmlspecialchars($user['phone']); ?></p>
        <p><strong><i class="ri-file-list-line myicon"></i>Reference Number :</strong> <?php echo htmlspecialchars($user['reference_number']); ?></p>
    </div>
    <!-- Right side -->
    <div class="col-6">
    <p>
        <strong>
            <i class="ri-code-line myicon"></i> Code :
        </strong>
        <span id="user-number" style="font-weight: normal; color: #333;"><?php echo htmlspecialchars($user['my_number']); ?></span>
        <i class="ri-clipboard-line" 
           style="cursor: pointer; margin-left: 4px; color: #333;" 
           onclick="copyToClipboard()"></i> <!-- Clickable copy icon -->
    </p>

    <script>
        function copyToClipboard() {
            const number = document.getElementById('user-number').innerText; // Get the user number
            navigator.clipboard.writeText(number) // Copy the number to clipboard
                .then(() => {
                    alert("Number copied!"); // Show success message
                })
                .catch(err => {
                    console.error("Failed to copy: ", err); // Log any errors
                });
        }
    </script>        <p><strong><i class="ri-calendar-line myicon"></i>Registration Date :</strong> <?php echo htmlspecialchars($user['created_at']); ?></p>
        <p><strong><i class="ri-wallet-line myicon"></i>Total Balance :</strong> <?php echo htmlspecialchars($netBalance); ?></p>
    </div>
</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- Box for Total Balance -->
        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Total Balance</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($netBalance); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                </div>
            </div>
        </div>

        <!-- Box for Total Withdrawals -->
        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Total Withdrawals</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($userWithdraw); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-danger-focus px-6 py-2 rounded-2 fw-medium text-danger-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayWithdraw); ?> <i class="ri-arrow-down-line"></i>
                        </span> Today
                    </p>
                </div>
            </div>
        </div>

        <!-- Box for Users Referred by You -->
        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Users Referred by You</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($refUserCount); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayRefUserCount); ?> <i class="ri-user-add-line"></i>
                        </span>
                        Today
                    </p>
                </div>
            </div>
        </div>

        

 <?php include './chart.php' ?>


        <div class="col-lg-12">
            <div class="card">
                <div class="card-header">
                    <h5 class="card-title mb-0">Reference  Users</h5>
                </div>
                <div class="card-body">
                    <div id="dataTable_wrapper" class="dt-container dt-empty-footer">
                        <div class="dt-layout-row dt-layout-table">
                            <div class="dt-layout-cell">
                                <table class="table bordered-table mb-0 dataTable" id="dataTable" data-page-length="10" style="width: 100%;">
                                    <colgroup>

                                        <style>
                                            table.dataTable th.dt-type-numeric,
                                            table.dataTable th.dt-type-date,
                                            table.dataTable td.dt-type-numeric,
                                            table.dataTable td.dt-type-date {
                                                text-align: start !important;
                                            }
                                        </style>

                                    <thead style="text-align: start !important;">
                                        <tr>
                                            <th scope="col">S.L</th>
                                            <th scope="col">Name</th>
                                            <th scope="col">Phone</th>
                                            <th scope="col">Reference Number</th>
                                            <th scope="col">Created At</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        // Prepare query to fetch users referred by the current user using my_number
                                        $transactionsQuery = "SELECT name, phone, reference_number, created_at 
                                                       FROM MLM_users 
                                                       WHERE reference_number = ?";
                                        $stmt = $conn->prepare($transactionsQuery);
                                        $stmt->bind_param("s", $user['my_number']); // Bind my_number as string
                                        $stmt->execute();
                                        $transactions = $stmt->get_result();
                                        $counter = 1;

                                        if ($transactions->num_rows > 0) {
                                            while ($transaction = $transactions->fetch_assoc()) {
                                                echo "<tr>
                                            <td>{$counter}</td>
                                            <td>" . htmlspecialchars($transaction['name']) . "</td>
                                            <td>" . htmlspecialchars($transaction['phone']) . "</td>
                                            <td>" . htmlspecialchars($transaction['reference_number']) . "</td>
                                            <td>" . htmlspecialchars($transaction['created_at']) . "</td>
                                        </tr>";
                                                $counter++;
                                            }
                                        } else {
                                            echo "<tr><td colspan='5' class='text-center'>No Data Found</td></tr>";
                                        }
                                        ?>
                                    </tbody>
                                    </colgroup>
                                </table>
                            </div>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
</div>



<?php include 'footer.php'; ?>