<?php
session_start();

include 'header.php';
include 'db.php';
$userId = isset($_GET['user_id']) ? (int)$_GET['user_id'] : 33;

if (!isset($_SESSION['user_id'])) {
    $_SESSION['user_id'] = $userId;
}


$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number'];
} else {
    echo "No user found with the provided ID.";
    exit;
}

function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0;
}

$userBalance = fetchTotalAmount($conn, $userId, 'add');
if ($userBalance === false) {
    die("Error fetching user balance.");
}

$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal');
if ($userWithdraw === false) {
    die("Error fetching user withdrawals.");
}

$userWithdraw = abs($userWithdraw);

$netBalance = $userBalance - $userWithdraw;

// echo "Net Balance = " . $userBalance . " - " . $userWithdraw . " = " . $netBalance . "<br>";

$todayCondition = 'AND DATE(created_at) = CURDATE()';
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition);
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition);

$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;


?>


<div class="dashboard-main-body" id="print">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">Dashboard </h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">Summary</li>
        </ul>
    </div>

    <style>
        .myicon {
            margin-right: 6px;
        }

        /* Print styles */
        @media print {
            .print-button {
                display: none; /* Hide print button during printing */
            }

            /* Other print styles */
            .dashboard-main-body {
                -webkit-print-color-adjust: exact; /* Ensure background colors are printed */
                color-adjust: exact;
            }
        }
    </style>

    <script>
        function printInvoice() {
            window.print(); // This will open the print dialog for the entire page
        }
    </script>

    <div class="row gy-4">
        <div class="col-lg-12">
            <div class="card-header">
                <div class="d-flex flex-wrap align-items-center justify-content-end gap-2">
                    <button type="button" class="btn btn-sm btn-danger radius-8 d-inline-flex align-items-center gap-1 print-button" onclick="printInvoice()">
                        <iconify-icon icon="basil:printer-outline" class="text-xl"></iconify-icon>
                        Print
                    </button>
                </div>
            </div>
        </div>

        <div class="col-lg-12">
            <div class="shadow-4 border radius-8" style="background-color: white;">
                <div class="p-20">
                    <?php if ($user['approved'] == 0): ?>
                        <p>Thank you for registering! Please pay your fees using the QR code below and send a screenshot to this phone number: <strong>6353818433</strong></p>
                        <img src="https://upload.wikimedia.org/wikipedia/commons/thumb/d/d0/QR_code_for_mobile_English_Wikipedia.svg/800px-QR_code_for-mobile_English_Wikipedia.svg.png" alt="QR Code">
                    <?php else: ?>
                        <div class="row">
                            <div class="col-6">
                                <p><strong><i class="ri-user-line myicon"></i>Name :</strong> <?php echo htmlspecialchars($user['name']); ?></p>
                                <p><strong><i class="ri-phone-line myicon"></i>Phone :</strong> <?php echo htmlspecialchars($user['phone']); ?></p>
                                <p><strong><i class="ri-file-list-line myicon"></i>Reference Number :</strong> <?php echo htmlspecialchars($user['reference_number']); ?></p>
                            </div>
                            <div class="col-6">
                                <p>
                                    <strong>
                                        <i class="ri-code-line myicon"></i> Code :
                                    </strong>
                                    <span id="user-number" style="font-weight: normal; color: #333;"><?php echo htmlspecialchars($user['my_number']); ?></span>
                                    <i class="ri-clipboard-line"
                                       style="cursor: pointer; margin-left: 4px; color: #333;"
                                       onclick="copyToClipboard()"></i> 
                                </p>
                                <script>
                                    function copyToClipboard() {
                                        const number = document.getElementById('user-number').innerText;
                                        navigator.clipboard.writeText(number) 
                                            .then(() => {
                                                alert("Number copied!"); 
                                            })
                                            .catch(err => {
                                                console.error("Failed to copy: ", err); 
                                            });
                                    }
                                </script>
                                <p><strong><i class="ri-calendar-line myicon"></i>Registration Date :</strong> <?php echo htmlspecialchars($user['created_at']); ?></p>
                                <p><strong><i class="ri-wallet-line myicon"></i>Total Balance :</strong> <?php echo htmlspecialchars($netBalance); ?></p>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Total Balance</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($netBalance); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                </div>
            </div>
        </div>

        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Total Withdrawals</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($userWithdraw); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-danger-focus px-6 py-2 rounded-2 fw-medium text-danger-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayWithdraw); ?> <i class="ri-arrow-down-line"></i>
                        </span> Today
                    </p>
                </div>
            </div>
        </div>

        <div class="col-lg-4 col-sm-6">
            <div class="card px-24 py-16 shadow-none radius-12 border h-100 ">
                <div class="card-body p-0">
                    <h6 class="fw-semibold mb-0">Users Referred by You</h6>
                    <p class="text-lg"><?php echo htmlspecialchars($refUserCount); ?></p>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayRefUserCount); ?> <i class="ri-user-add-line"></i>
                        </span>
                        Today
                    </p>
                </div>
            </div>
        </div>

        <div class="col-lg-12">
            <div class="card">
                <div class="card-header">
                    <h5 class="card-title mb-0">Reference Users</h5>
                </div>
                <div class="card-body">
                    <div id="dataTable_wrapper" class="dt-container dt-empty-footer">
                        <div class="dt-layout-row dt-layout-table">
                            <div class="dt-layout-cell">
                                <table class="table bordered-table mb-0 dataTable" id="dataTable" data-page-length="10" style="width: 100%;">
                                    <colgroup>
                                        <style>
                                            table.dataTable th.dt-type-numeric,
                                            table.dataTable th.dt-type-date,
                                            table.dataTable td.dt-type-numeric,
                                            table.dataTable td.dt-type-date {
                                                text-align: start !important;
                                            }
                                        </style>
                                    </colgroup>
                                    <thead style="text-align: start !important;">
                                        <tr>
                                            <th scope="col">S.L</th>
                                            <th scope="col">Name</th>
                                            <th scope="col">Phone</th>
                                            <th scope="col">Reference Number</th>
                                            <th scope="col">Created At</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        // Prepare query to fetch users referred by the current user using my_number
                                        $transactionsQuery = "SELECT name, phone, reference_number, created_at 
                                                       FROM MLM_users 
                                                       WHERE reference_number = ?";
                                        $stmt = $conn->prepare($transactionsQuery);
                                        $stmt->bind_param("s", $user['my_number']); // Bind my_number as string
                                        $stmt->execute();
                                        $transactions = $stmt->get_result();
                                        $counter = 1;

                                        if ($transactions->num_rows > 0) {
                                            while ($transaction = $transactions->fetch_assoc()) {
                                                echo "<tr>
                                            <td>{$counter}</td>
                                            <td>" . htmlspecialchars($transaction['name']) . "</td>
                                            <td>" . htmlspecialchars($transaction['phone']) . "</td>
                                            <td>" . htmlspecialchars($transaction['reference_number']) . "</td>
                                            <td>" . htmlspecialchars($transaction['created_at']) . "</td>
                                        </tr>";
                                                $counter++;
                                            }
                                        } else {
                                            echo "<tr><td colspan='5' class='text-center'>No records found.</td></tr>";
                                        }
                                        ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php  include './user_chart.php' ?>
    </div>
</div>


<?php
include 'footer.php';
?>