<?php

include 'header.php';
session_start(); 

include 'db.php'; 

$userId = 120;

// Uncomment the following lines if you want to start a session for user_id
// if (!isset($_SESSION['user_id'])) {
//     $_SESSION['user_id'] = $userId; 
// }

$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; 
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Function to fetch total amounts based on wallet type and optionally a date condition
function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    // Append date condition if provided
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; // Return total or 0 if null
}

// Fetch balances and withdrawals with error handling
$userBalance = fetchTotalAmount($conn, $userId, 'add'); // Total balance
if ($userBalance === false) {
    die("Error fetching user balance."); // Handle error in fetching user balance
}

$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal'); // Total withdrawals
if ($userWithdraw === false) {
    die("Error fetching user withdrawals."); // Handle error in fetching user withdrawals
}

// Ensure withdrawals are treated as positive for calculation
$userWithdraw = abs($userWithdraw); // Convert withdrawals to positive if needed

// Calculate net balance
$netBalance = $userBalance - $userWithdraw; // Correctly calculate net balance

// Display net balance
// echo "Net Balance = " . $userBalance . " - " . $userWithdraw . " = " . $netBalance . "<br>";

// Fetch today's balance and withdrawals
$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals

// Fetch reference user's total balance
$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

// Fetch count of users who used the current user's reference number
$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

// Fetch count of users referred by the current user today
$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Get user ID from session, default to 120 for this example
$user_id = 120;

// SQL query to fetch user's wallet transactions
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? 
          ORDER BY `created_at` DESC";

// Prepare and execute the statement
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result(); 

// Fetch all transactions
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Debug output to check the fetched transactions
if (empty($transactions)) {
    // echo "No transactions found for User ID: $user_id"; // Add this line for debugging
} else {
    // Optionally display transactions here
}

// New section can be added here but is currently commented out
/*
$additionalQuery = "SELECT * FROM some_table WHERE condition = ?";
$stmt = $conn->prepare($additionalQuery);
$stmt->bind_param("s", $someVariable);
$stmt->execute();
$additionalResult = $stmt->get_result();
$additionalData = $additionalResult->fetch_all(MYSQLI_ASSOC);

// Process and display additional data as needed
*/

?>


    <!-- App Capsule -->
   <div id="appCapsule">

        <!-- Wallet Card -->
        <div class="section wallet-card-section pt-1">
            <div class="wallet-card">
                <!-- Balance -->
                <div class="balance">
                    <div class="left">
                        <span class="title">Total Balance</span>
                        <h1 class="total">₹<?php echo htmlspecialchars($netBalance); ?></h1>
                        <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                        ₹ <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                    </div>
                    <div class="right">
                        <a href="#" class="button" data-bs-toggle="modal" data-bs-target="#withdrawalModal">
                            <ion-icon name="add-outline"></ion-icon>
                        </a>
                    </div>
                </div>

            </div>
        </div>
        <!-- Wallet Card -->


 


        <div class="section mt-2" >
    <div class="card" style="padding: 20px; margin-top: 20px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
            <div style="display: flex; gap: 10px;">
                <input type="text" id="searchInput" class="form-control form-control-sm w-auto" placeholder="Search..." />
                <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all">All</option>
                    <option value="add">Add</option>
                    <option value="withdrawal">Withdrawal</option>
                </select>
            </div>
        </div>
        <div class="table-responsive">
            <table class="table bordered-table mb-0">
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">Description (Transaction Type)</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Amount</th>
                        <th scope="col">Wallet Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
                    <?php
                    $counter = 1;
                    foreach ($transactions as $transaction) {
                        echo "<tr>";
                        echo "<td>{$counter}</td>";
                        echo "<td>{$transaction['user_id']}</td>";
                        echo "<td>{$transaction['description']}</td>";
                        echo "<td>{$transaction['created_at']}</td>";
                        echo "<td>₹" . number_format($transaction['amount'], 2) . "</td>";
                        echo "<td>
                                <span class='px-24 py-4 rounded-pill fw-medium text-sm " . 
                                ($transaction['wallet_type'] == 'add' ? 'bg-wallet-add text-wallet-add' : 'bg-wallet-withdrawal text-wallet-withdrawal') . "'>
                                    " . ucfirst($transaction['wallet_type']) . "
                                </span>
                              </td>";
                        echo "</tr>";
                        $counter++;
                    }
                    ?>
                </tbody>
            </table>
        </div>
        <div id="pagination" class="mt-3 d-flex justify-content-center"></div>
    </div>
</div>

<script>
    // Search and filter logic
    const searchInput = document.getElementById('searchInput');
    const transactionFilter = document.getElementById('transactionFilter');
    const transactionTableBody = document.getElementById('transactionTableBody');

    // Function to filter transactions based on search and filter criteria
    function filterTransactions() {
        const searchTerm = searchInput.value.toLowerCase();
        const filterValue = transactionFilter.value.toLowerCase();
        const rows = transactionTableBody.getElementsByTagName('tr');

        for (let row of rows) {
            const description = row.cells[2].innerText.toLowerCase();
            const walletType = row.cells[5].innerText.toLowerCase();
            const matchesSearch = description.includes(searchTerm) || walletType.includes(searchTerm);
            const matchesFilter = filterValue === 'all' || walletType === filterValue;

            row.style.display = (matchesSearch && matchesFilter) ? '' : 'none';
        }
    }

    // Add event listeners for search input and filter dropdown
    searchInput.addEventListener('input', filterTransactions);
    transactionFilter.addEventListener('change', filterTransactions);
</script>

<style>
    /* .bg-wallet-withdrawal {
        background-color: #f4433640 !important; 
    } */

    .text-wallet-withdrawal {
        color: #c62828 !important; 
    }

    /* .bg-wallet-add {
        background-color: rgba(76, 175, 80, 0.1) !important; 
    } */

    .text-wallet-add {
        color: #00796b !important;
    }
</style>

<?php include 'footer.php'; ?>


<div class="modal fade action-sheet" id="withdrawalModal" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Request Withdrawal</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <div class="action-sheet-content">
                    <?php if (isset($message) && !empty($message)): ?>
                        <div class="alert alert-danger"><?php echo htmlspecialchars($message); ?></div>
                    <?php endif; ?>
                    <form id="withdrawalForm" method="POST" action="">
                        <div class="form-group basic mb-20">
                            <label class="label fw-semibold text-primary-light text-sm mb-8" for="user_name">
                                User Name <span class="text-danger-600">*</span>
                            </label>
                            <input type="text" class="form-control radius-8" id="user_name" name="user_name" required>
                        </div>
                        <div class="form-group basic mb-20">
                            <label class="label fw-semibold text-primary-light text-sm mb-8" for="bank_name">
                                Bank Name <span class="text-danger-600">*</span>
                            </label>
                            <input type="text" class="form-control radius-8" id="bank_name" name="bank_name" required>
                        </div>
                        <div class="form-group basic mb-20">
                            <label class="label fw-semibold text-primary-light text-sm mb-8" for="bank_number">
                                Bank Number <span class="text-danger-600">*</span>
                            </label>
                            <input type="text" class="form-control radius-8" id="bank_number" name="bank_number" required>
                        </div>
                        <div class="form-group basic mb-20">
                            <label class="label fw-semibold text-primary-light text-sm mb-8" for="branch">
                                Branch <span class="text-danger-600">*</span>
                            </label>
                            <input type="text" class="form-control radius-8" id="branch" name="branch" required>
                        </div>
                        <div class="form-group basic mb-20">
                            <label class="label fw-semibold text-primary-light text-sm mb-8" for="withdrawal_amount">
                                Withdrawal Amount <span class="text-danger-600">*</span>
                            </label>
                            <input type="number" class="form-control radius-8" id="withdrawal_amount" name="withdrawal_amount" min="101" required>
                            <div id="withdrawal_error" class="text-danger-600 mt-2" style="display: none;">
                                Withdrawal amount must be greater than 100.
                            </div>
                        </div>

                        <div class="form-group basic">
                            <div class="d-flex justify-content-end">
                                <button type="button" class="btn btn-light" data-bs-dismiss="modal">Cancel</button>
                                <button type="submit" class="btn btn-primary ms-2">Request</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
