<?php
session_start(); 
include 'header.php';
include 'db.php'; 

function checkPhoneNumberExists($phone) {
    global $conn; 
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE phone = ?");
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $stmt->store_result();
    return $stmt->num_rows > 0; 
}

function registerUserInDB($name, $phone, $referenceNumber) {
    global $conn; 

    $stmt = $conn->prepare("INSERT INTO MLM_users (name, phone, reference_number, my_number, created_at, total_balance, approved) VALUES (?, ?, ?, '', NOW(), 0, 0)");
    $stmt->bind_param("sss", $name, $phone, $referenceNumber);

    if ($stmt->execute()) {
        return $stmt->insert_id; 
    } else {
        return false;
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = $_POST['name'];
    $phone = $_POST['phone'];
    $referenceNumber = $_POST['referenceNumber'];

    if (checkPhoneNumberExists($phone)) {
        $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE phone = ?");
        $stmt->bind_param("s", $phone);
        $stmt->execute();
        $result = $stmt->get_result();
        $user = $result->fetch_assoc();
        
        $_SESSION['user_id'] = $user['id']; 
        header("Location: ./user-admin/index.php"); 
        exit(); 
    } else {
        $userId = registerUserInDB($name, $phone, $referenceNumber);
        if ($userId) {
            $_SESSION['user_id'] = $userId;
            header("Location: ./user-panel/index.php"); 
            exit(); 
        } else {
            echo "Registration failed. Please try again.";
        }
    }
}
?>

<div class="bg-light">
    <div id="banner1" class="banner py-5">
        <div class="container">
            <div class="row">
                <div class="col-md-7 col-lg-6 align-self-center">
                    <h2 class="title my-3 font-weight-bold">Give your Business Real Boost Now!</h2>
                    <p class="mt-4 mb-3">To accomplish great things, we must not only act, but also dream; not only plan, but also believe.</p>

                    <div class="mt-4">
                        <!-- Phone number input -->
                        <div class="banner1-group mb-3" id="phoneField">
                            <form onsubmit="return false;"> <!-- Prevent form submission -->
                                <div class="input-group">
                                    <div style="position: relative;">
                                        <input type="text" id="phoneNumber" class="form-control border-0 line-height text-email emin"
                                            style="background-color: #ffffff !important; padding-left: 50px;"
                                            required 
                                            onfocus="if (this.value === '') { this.value = ''; }"
                                            oninput="if (this.value.startsWith('+91 | ')) { this.value = this.value.replace('+91 | ', ''); }"
                                            placeholder="Enter Your number">
                                        <span style="position: absolute; left: 10px; top: 50%; transform: translateY(-50%); color: #333;">+91 |</span>
                                    </div>
                                    <div class="input-group-append">
                                        <button class="btn btn-success-gradiant line-height font-weight-medium font-16 text-white border-0 btn-sub" id="sendOtp" onclick="phoneAuth();">Send OTP</button>
                                    </div>
                                </div>
                            </form>
                        </div>

                        <!-- OTP input field (Hidden initially) -->
                        <div class="banner1-group mb-3" id="otpField" style="display: none;">
                            <div class="input-group">
                                <input type="text" class="form-control border-0 line-height text-email" style="background-color: #ffffff !important;" placeholder="Enter OTP" id="verificationCode" required>
                                <div class="input-group-append">
                                    <button class="btn btn-success-gradiant line-height font-weight-medium font-16 text-white border-0 btn-sub" onclick="codeverify();">Verify OTP</button>
                                </div>
                            </div>
                            <div id="otpCountdown" class="mt-2" style="font-size: 14px; color: #dc3545;"></div>
                            <div id="resendLink" class="mt-2" style="display: none;">
                                <a href="#" onclick="resendOtp();">Resend OTP</a>
                            </div>
                        </div>

                        <!-- Registration form (Hidden initially) -->
                        <div class="banner1-group mb-3" id="registrationField" style="display: none;">
                            <form method="POST" action="">
                                <div class="input-group mb-3">
                                    <input type="text" class="form-control border-0 line-height text-email" 
                                        style="color: #8d97ad; border-radius: 36px; text-indent: 5px; width: 70% !important; 
                                        box-shadow: -5px 0 30px 0 rgba(0, 0, 0, 0.05);" 
                                        placeholder="Reference Number" id="referenceNumber" name="referenceNumber">
                                </div>
                                <div class="input-group mb-3">
                                    <input type="text" class="form-control border-0 line-height text-email" 
                                        style="color: #8d97ad; border-radius: 36px; text-indent: 5px; width: 70% !important; 
                                        box-shadow: -5px 0 30px 0 rgba(0, 0, 0, 0.05);" 
                                        placeholder="Name" id="name" name="name" required>
                                </div>
                                <div class="input-group mb-3">
                                    <span style="background-color: #ffffff;  border-radius: 36px 0 0 36px; padding: 10px; display: inline-block; color: #333;">+91 |</span>
                                    <input type="tel" id="phoneNumber" class="form-control border-0 line-height text-email" 
                                        style="background-color: #ffffff !important; border-radius: 0 36px 36px 0; padding-left: 10px;"
                                        required 
                                        placeholder="Phone Number" name="phone" 
                                        oninput="this.value = this.value.replace(/[^0-9]/g, '');">
                                </div>
                                <div class="input-group-append">
                                    <button class="btn btn-success-gradiant line-height font-weight-medium font-16 text-white border-0 btn-sub" 
                                        style="border-radius: 36px; width: auto; padding: 0 16px; cursor: pointer; 
                                        box-shadow: 5px 0 30px 0 rgba(0, 0, 0, 0.05); transition: all 0.5s ease-in-out;" 
                                        type="submit">Register</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="col-md-5 col-lg-6 align-self-center ml-auto">
                    <img src="https://www.wrappixel.com/demos/ui-kit/wrapkit/assets/images/form-banners/banner1/banner-img.png" alt="We are Digital Agency" class="img-fluid" />
                </div>
            </div>
        </div>
    </div>
</div>

<script src="https://www.gstatic.com/firebasejs/8.3.1/firebase-app.js"></script>
<script src="https://www.gstatic.com/firebasejs/8.3.1/firebase-auth.js"></script>
<script>
    var firebaseConfig = {
        apiKey: "AIzaSyCdP09prVY8cfEpXUwmwIxo8l9f7vWppv8",
        authDomain: "mlm-project-96d94.firebaseapp.com",
        projectId: "mlm-project-96d94",
        storageBucket: "mlm-project-96d94.appspot.com",
        messagingSenderId: "319115802196"
    };

    firebase.initializeApp(firebaseConfig);
    
    let countdownInterval;

    function showOtpField() {
        document.getElementById('phoneField').style.display = 'none';
        document.getElementById('otpField').style.display = 'block';
        startOtpCountdown(60);
    }

    function startOtpCountdown(seconds) {
        let timeLeft = seconds;
        const countdownElement = document.getElementById('otpCountdown');
        countdownElement.innerText = `OTP will expire in ${Math.floor(timeLeft / 60)}:${String(timeLeft % 60).padStart(2, '0')} seconds`;

        countdownInterval = setInterval(() => {
            timeLeft -= 1;
            if (timeLeft <= 0) {
                clearInterval(countdownInterval);
                countdownElement.innerText = "OTP expired.";
                document.getElementById('resendLink').style.display = 'block';
            } else {
                countdownElement.innerText = `OTP will expire in ${Math.floor(timeLeft / 60)}:${String(timeLeft % 60).padStart(2, '0')} seconds`;
            }
        }, 1000);
    }

    function phoneAuth() {
        const phoneNumber = document.getElementById('phoneNumber').value;
        const appVerifier = new firebase.auth.RecaptchaVerifier('sendOtp', {
            'size': 'invisible'
        });

        firebase.auth().signInWithPhoneNumber("+91" + phoneNumber, appVerifier)
            .then((confirmationResult) => {
                window.confirmationResult = confirmationResult;
                showOtpField();
            })
            .catch((error) => {
                alert("Error during phone authentication: " + error.message);
            });
    }

    function codeverify() {
        const verificationCode = document.getElementById('verificationCode').value;
        window.confirmationResult.confirm(verificationCode).then((result) => {
            document.getElementById('otpField').style.display = 'none';
            document.getElementById('registrationField').style.display = 'block';
        }).catch((error) => {
            alert("Error verifying OTP: " + error.message);
        });
    }

    function resendOtp() {
        clearInterval(countdownInterval);
        startOtpCountdown(60);
        phoneAuth();
    }
</script>

<?php include 'footer.php'; ?>
