<?php
include 'header.php';
session_start();
include 'db.php';

// Initialize user_id
$user_id = 120; // OR from URL parameter (e.g., ?user_id=33)
if (isset($_GET['user_id'])) {
    $user_id = (int)$_GET['user_id'];
}

// Check if user_id is set
if (!$user_id) {
    echo "User ID is not set.";
    exit;
}

// Initialize message variable
$message = '';

// Calculate total balance
$total_add = 0;
$total_withdrawal = 0;
$query = "SELECT `amount`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ?";

$stmt = $conn->prepare($query);
if ($stmt) {
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    // Sum the amounts based on wallet type
    while ($row = $result->fetch_assoc()) {
        if ($row['wallet_type'] === 'add') {
            $total_add += $row['amount'];
        } elseif ($row['wallet_type'] === 'withdrawal') {
            $total_withdrawal += $row['amount'];
        }
    }
    // Calculate total balance
    $total_balance = $total_add - $total_withdrawal;

    // Display total balance
}

// Close the statement
$stmt->close();

// Check if withdrawal amount is valid and does not exceed total balance
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['withdrawal_amount'])) {
    $withdrawal_amount = (float)$_POST['withdrawal_amount'];
    $user_name = htmlspecialchars(trim($_POST['user_name']));
    $bank_name = htmlspecialchars(trim($_POST['bank_name']));
    $bank_number = htmlspecialchars(trim($_POST['bank_number']));
    $branch = htmlspecialchars(trim($_POST['branch']));

    // Calculate total balance before withdrawal
    $total_balance = $total_add - $total_withdrawal;

    // Check if withdrawal amount is greater than total balance
    if ($withdrawal_amount > $total_balance) {
        $message = "You cannot withdraw this amount. Your total balance is only \${$total_balance}.";
    }
    // Check if withdrawal amount would drop balance below 100
    elseif ($total_balance - $withdrawal_amount < 100) {
        $message = "You cannot withdraw this amount. Please maintain a minimum balance of 100 MRP.";
    } else {
        // Prepare SQL for inserting withdrawal transaction
        $insertSql = "INSERT INTO payment_withdrawals (user_id, user_name, bank_name, bank_number, branch, withdrawal_amount, type, created_at) VALUES (?, ?, ?, ?, ?, ?, 'pending', NOW())";
        $stmtInsert = $conn->prepare($insertSql);

        // Bind parameters
        $stmtInsert->bind_param('issssd', $user_id, $user_name, $bank_name, $bank_number, $branch, $withdrawal_amount);

        // Execute and check if successful
        if ($stmtInsert->execute()) {
            $message = "Withdrawal request added successfully!";
            header("Location: withdrawals_req.php");
            exit; // Ensure script stops after redirection
        } else {
            $message = "Error adding withdrawal request: " . htmlspecialchars($stmtInsert->error); // Display the error
        }
    }
}

?>



<style>
    .bg-wallet-withdrawal {
        background-color: #f4433640 !important;
    }

    .text-wallet-withdrawal {
        color: #c62828 !important;
    }

    .bg-wallet-add {
        background-color: rgba(76, 175, 80, 0.1) !important;
    }

    .text-wallet-add {
        color: #00796b !important;
    }
</style>


<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">User Wallet</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard

                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">User Wallet</li>
        </ul>
    </div>

    <div class="card basic-data-table">
        <div class="card-body">


        
            <div class="row gy-4">
                <div class="col-xxl-6 col-xl-6 col-sm-6">
                    <div class="px-20 py-16 shadow-none radius-8 h-100 left-line line-bg-primary position-relative overflow-hidden">
                        <div class="d-flex flex-wrap align-items-center justify-content-between gap-1 mb-8">
                            <div>
                                <span class="mb-2 fw-medium text-secondary-light text-md">Total Balance</span>
                                <?php
                                // Calculate total balance
                                $total_add = 0;
                                $total_withdrawal = 0;
                                $query = "SELECT `amount`, `wallet_type` 
                                          FROM `wallet_transactions` 
                                          WHERE `user_id` = ?";

$wallet_type_class = '';
$wallet_type_text_class = '';

// Set unique class names based on wallet type
if ($row['wallet_type'] === 'add') {
    $wallet_type_class = 'bg-wallet-add'; // Unique background class for 'Add'
    $wallet_type_text_class = 'text-wallet-add'; // Unique text class for 'Add'
} elseif ($row['wallet_type'] === 'withdrawal') {
    $wallet_type_class = 'bg-wallet-withdrawal'; // Unique background class for 'Withdrawal'
    $wallet_type_text_class = 'text-wallet-withdrawal'; // Unique text class for 'Withdrawal'
}


                                $stmt = $conn->prepare($query);
                                if ($stmt) {
                                    $stmt->bind_param("i", $user_id);
                                    $stmt->execute();
                                    $result = $stmt->get_result();

                                    // Sum the amounts based on wallet type
                                    while ($row = $result->fetch_assoc()) {
                                        if ($row['wallet_type'] === 'add') {
                                            $total_add += $row['amount'];
                                        } elseif ($row['wallet_type'] === 'withdrawal') {
                                            $total_withdrawal += $row['amount'];
                                        }
                                    }
                                    // Calculate total balance
                                    $total_balance = $total_add - $total_withdrawal;

                                    // Display total balance
                                    echo "<h4 class='fw-semibold mb-1'>₹{$total_balance}</h4>";
                                }
                                // Close the statement
                                $stmt->close();
                                ?>
                         
                        </div>
                        </div>
                    </div>
                </div>
                <div class="col-xxl-6 col-xl-6 col-sm-6">
                    <div class="mt-24 d-flex justify-content-end">
                        <button type="button" class="btn btn-outline-primary d-flex align-items-center gap-2" data-bs-toggle="modal" data-bs-target="#withdrawalModal">
                            <i class="ri-repeat-2-line"></i> Withdrawal
                        </button>
                    </div>
                </div>
            </div>

            <div class="d-flex align-items-center flex-wrap gap-2 justify-content-between mb-20">
                <h6 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h6>
                <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all">All</option>
                    <option value="add">Add</option>
                    <option value="withdrawal">Withdrawal</option>
                </select>
            </div>
            <table class="table bordered-table mb-0" id="dataTable" data-page-length='10'>
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">Invoice</th>
                        <th scope="col">Transaction Type</th>
                        <th scope="col">Amount</th>
                        <th scope="col">Description</th>
                        <th scope="col">Wallet Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
                    <?php
                    session_start();
                    include 'db.php'; 

                    // Get user ID from session, default to 33 for this example
                    $user_id = 120;

                    // SQL query to fetch user's wallet transactions
                    $query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
                              FROM `wallet_transactions` 
                              WHERE `user_id` = ?";

                    // Prepare and execute the statement
                    $stmt = $conn->prepare($query);
                    if ($stmt) {
                        $stmt->bind_param("i", $user_id);
                        $stmt->execute();
                        $result = $stmt->get_result();

                        // Initialize serial number counter
                        $sl = 1;

                        // Check if there are any transactions
                        if ($result->num_rows > 0) {
                            // Fetch and display each transaction row
                            while ($row = $result->fetch_assoc()) {
                                // Debugging line to check retrieved wallet type
                                error_log("Retrieved wallet type: " . $row['wallet_type']); // Log wallet type to PHP error log

                                $wallet_type_class = '';
                                $wallet_type_text_class = '';

                                // Set unique class names based on wallet type
                                if ($row['wallet_type'] === 'add') {
                                    $wallet_type_class = 'bg-wallet-add'; // Unique background class for 'Add'
                                    $wallet_type_text_class = 'text-wallet-add'; // Unique text class for 'Add'
                                } elseif ($row['wallet_type'] === 'withdrawal') {
                                    $wallet_type_class = 'bg-wallet-withdrawal'; // Unique background class for 'Withdrawal'
                                    $wallet_type_text_class = 'text-wallet-withdrawal'; // Unique text class for 'Withdrawal'
                                }

                                echo "<tr data-wallet-type='{$row['wallet_type']}'>
                                        <td>
                                            <div class='form-check style-check d-flex align-items-center'>
                                                <input class='form-check-input' type='checkbox'>
                                                <label class='form-check-label'>{$sl}</label>
                                            </div>
                                        </td>
                                        <td><a href='javascript:void(0)' class='text-primary-600'>#{$row['id']}</a></td>
                                        <td>{$row['description']}</td>
                                        <td>{$row['created_at']}</td>
                                        <td>₹{$row['amount']}</td>
                                        <td>
                                            <span class='px-24 py-4 rounded-pill fw-medium text-sm {$wallet_type_class} {$wallet_type_text_class}'>
                                                {$row['wallet_type']}
                                            </span>
                                        </td>
                                      </tr>";
                                $sl++;
                            }
                        } else {
                            // echo "<tr><td colspan='6'>No transactions found.</td></tr>";
                        }

                        // Close the statement
                        $stmt->close();
                    }

                    // Close the connection
                    $conn->close();
                    ?>
                </tbody>
            </table>

        </div>
    </div>
</div>




<?php include 'footer.php'; ?>

<!-- Withdrawal Modal -->
<div class="modal fade" id="withdrawalModal" tabindex="-1" aria-labelledby="withdrawalModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="withdrawalModalLabel">Request Withdrawal</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <?php if (isset($message) && !empty($message)): ?>
                    <div class="alert alert-danger"><?php echo htmlspecialchars($message); ?></div>
                <?php endif; ?>
                <form id="withdrawalForm" method="POST" action="">
                    <div class="mb-20">
                        <label for="user_name" class="form-label fw-semibold text-primary-light text-sm mb-8">User Name <span class="text-danger-600">*</span></label>
                        <input type="text" class="form-control radius-8" id="user_name" name="user_name" required>
                    </div>
                    <div class="mb-20">
                        <label for="bank_name" class="form-label fw-semibold text-primary-light text-sm mb-8">Bank Name <span class="text-danger-600">*</span></label>
                        <input type="text" class="form-control radius-8" id="bank_name" name="bank_name" required>
                    </div>
                    <div class="mb-20">
                        <label for="bank_number" class="form-label fw-semibold text-primary-light text-sm mb-8">Bank Number <span class="text-danger-600">*</span></label>
                        <input type="text" class="form-control radius-8" id="bank_number" name="bank_number" required>
                    </div>
                    <div class="mb-20">
                        <label for="branch" class="form-label fw-semibold text-primary-light text-sm mb-8">Branch <span class="text-danger-600">*</span></label>
                        <input type="text" class="form-control radius-8" id="branch" name="branch" required>
                    </div>
                    <div class="mb-20">
                        <label for="withdrawal_amount" class="form-label fw-semibold text-primary-light text-sm mb-8">
                            Withdrawal Amount <span class="text-danger-600">*</span>
                        </label>
                        <input type="number" class="form-control radius-8" id="withdrawal_amount" name="withdrawal_amount" min="101" required>
                        <div id="withdrawal_error" class="text-danger-600 mt-2" style="display: none;">
                            Withdrawal amount must be greater than 100.
                        </div>
                    </div>

                    <div class="d-flex justify-content-end">
                        <button type="button" class="btn btn-light" data-bs-dismiss="modal">Cancel</button>
                        <button type="submit" class="btn btn-primary ms-2">Request</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<script>
    // Show the modal on page load if there's a message
    <?php if (isset($message) && !empty($message)): ?>
        var withdrawalModal = new bootstrap.Modal(document.getElementById('withdrawalModal'), {
            backdrop: 'static',
            keyboard: false
        });
        withdrawalModal.show();
    <?php endif; ?>

    // Handle form submission
    document.getElementById('withdrawalForm').addEventListener('submit', function(event) {
        event.preventDefault(); // Prevent the default form submission

        // Check the withdrawal amount
        const withdrawalAmount = parseFloat(document.getElementById('withdrawal_amount').value);
        const errorDiv = document.getElementById('withdrawal_error');

        // Validate withdrawal amount
        if (isNaN(withdrawalAmount) || withdrawalAmount <= 100) {
            errorDiv.style.display = 'block'; // Show the error message
        } else {
            errorDiv.style.display = 'none'; // Hide error message if valid
            this.submit(); // Submit the form if everything is valid
        }
    });
</script>


<script>
    document.getElementById('transactionFilter').addEventListener('change', function() {
        const filterValue = this.value;

        // Get all table rows
        const rows = document.querySelectorAll('#transactionTableBody tr');

        rows.forEach(row => {
            const walletType = row.getAttribute('data-wallet-type');

            // console.log("Row wallet type:", walletType, "Filter value:", filterValue);

            if (filterValue === 'all' || filterValue === walletType) {
                row.style.display = '';
            } else {
                row.style.display = 'none';
            }
        });
    });
</script>